@@ -37,6 +37,7 @@
 #include <QTimer>
 #include <QGraphicsPixmapItem>
 #include <QShortcut>
+#include <QListWidgetItem>
 
 SiteInfo::SiteInfo(WebView *view)
     : QDialog(view)
@@ -58,6 +59,7 @@ SiteInfo::SiteInfo(WebView *view)
 
     ui->listWidget->item(0)->setIcon(QIcon::fromTheme(QSL("document-properties"), QIcon(QSL(":/icons/preferences/document-properties.png"))));
     ui->listWidget->item(1)->setIcon(QIcon::fromTheme(QSL("applications-graphics"), QIcon(QSL(":/icons/preferences/applications-graphics.png"))));
+    ui->listWidget->item(2)->setIcon(QIcon(QStringLiteral(":/icons/preferences/privacy.svg")));
     ui->listWidget->item(0)->setSelected(true);
 
     // General
@@ -122,27 +124,31 @@ SiteInfo::SiteInfo(WebView *view)
         }
     });
 
+    /* Permissions */
+    addSiteSettings();
+
     connect(ui->saveButton, SIGNAL(clicked(QAbstractButton*)), this, SLOT(saveImage()));
     connect(ui->listWidget, SIGNAL(currentRowChanged(int)), ui->stackedWidget, SLOT(setCurrentIndex(int)));
     connect(ui->treeImages, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)), this, SLOT(showImagePreview(QTreeWidgetItem*)));
     connect(ui->treeImages, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(imagesCustomContextMenuRequested(QPoint)));
     connect(ui->treeTags, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(tagsCustomContextMenuRequested(QPoint)));
+    connect(this, &QDialog::accepted, this, &SiteInfo::saveSiteSettings);
 
     auto *shortcutTagsCopyAll = new QShortcut(QKeySequence(QSL("Ctrl+C")), ui->treeTags);
     shortcutTagsCopyAll->setContext(Qt::WidgetShortcut);
-    connect(shortcutTagsCopyAll, &QShortcut::activated, [=]{copySelectedItems(ui->treeTags, false);});
+    connect(shortcutTagsCopyAll, &QShortcut::activated, this, [=]{copySelectedItems(ui->treeTags, false);});
 
     auto *shortcutTagsCopyValues = new QShortcut(QKeySequence(QSL("Ctrl+Shift+C")), ui->treeTags);
     shortcutTagsCopyValues->setContext(Qt::WidgetShortcut);
-    connect(shortcutTagsCopyValues, &QShortcut::activated, [=]{copySelectedItems(ui->treeTags, true);});
+    connect(shortcutTagsCopyValues, &QShortcut::activated, this, [=]{copySelectedItems(ui->treeTags, true);});
 
     auto *shortcutImagesCopyAll = new QShortcut(QKeySequence(QSL("Ctrl+C")), ui->treeImages);
     shortcutImagesCopyAll->setContext(Qt::WidgetShortcut);
-    connect(shortcutImagesCopyAll, &QShortcut::activated, [=]{copySelectedItems(ui->treeImages, false);});
+    connect(shortcutImagesCopyAll, &QShortcut::activated, this, [=]{copySelectedItems(ui->treeImages, false);});
 
     auto *shortcutImagesCopyValues = new QShortcut(QKeySequence(QSL("Ctrl+Shift+C")), ui->treeImages);
     shortcutImagesCopyValues->setContext(Qt::WidgetShortcut);
-    connect(shortcutImagesCopyValues, &QShortcut::activated, [=]{copySelectedItems(ui->treeImages, true);});
+    connect(shortcutImagesCopyValues, &QShortcut::activated, this, [=]{copySelectedItems(ui->treeImages, true);});
 
     ui->treeImages->setContextMenuPolicy(Qt::CustomContextMenu);
     ui->treeImages->sortByColumn(-1, Qt::AscendingOrder);
@@ -323,3 +329,76 @@ SiteInfo::~SiteInfo()
     delete ui;
     delete m_certWidget;
 }
+
+SiteInfoPermissionItem* SiteInfo::addPermissionOption(SiteSettingsManager::Permission perm)
+{
+    auto* listItem = new QListWidgetItem(ui->listPermissions);
+    auto* optionItem = new SiteInfoPermissionItem(perm, this);
+
+    ui->listPermissions->setItemWidget(listItem, optionItem);
+    listItem->setSizeHint(optionItem->sizeHint());
+
+    return optionItem;
+}
+
+void SiteInfo::addSiteSettings()
+{
+    auto siteSettings = mApp->siteSettingsManager()->getSiteSettings(m_baseUrl);
+    const auto supportedAttribute = mApp->siteSettingsManager()->getSupportedAttribute();
+    for (const auto &attribute : supportedAttribute) {
+        SiteInfoPermissionItem *item = addPermissionOption(siteSettings.attributes[attribute]);
+        item->setAttribute(attribute);
+    }
+    const auto supportedFeatures = mApp->siteSettingsManager()->getSupportedFeatures();
+    for (const auto &feature : supportedFeatures) {
+        SiteInfoPermissionItem *item = addPermissionOption(siteSettings.features[feature]);
+        item->setFeature(feature);
+    }
+    SiteInfoPermissionItem *item = addPermissionOption(siteSettings.AllowCookies);
+    item->setOption(SiteSettingsManager::poAllowCookies);
+}
+
+void SiteInfo::saveSiteSettings()
+{
+    SiteSettings siteSettings;
+    int index = 0;
+    auto supportedAttribute = mApp->siteSettingsManager()->getSupportedAttribute();
+    auto supportedFeatures = mApp->siteSettingsManager()->getSupportedFeatures();
+
+    for (int i = 0; i < supportedAttribute.size(); ++i, ++index) {
+        auto* item = static_cast<SiteInfoPermissionItem*>(ui->listPermissions->itemWidget(ui->listPermissions->item(index)));
+        siteSettings.attributes[supportedAttribute[i]] = item->permission();
+    }
+    for (int i = 0; i < supportedFeatures.size(); ++i, ++index) {
+        auto* item = static_cast<SiteInfoPermissionItem*>(ui->listPermissions->itemWidget(ui->listPermissions->item(index)));
+        siteSettings.features[supportedFeatures[i]] = item->permission();
+    }
+    auto* item = static_cast<SiteInfoPermissionItem*>(ui->listPermissions->itemWidget(ui->listPermissions->item(index++)));
+    siteSettings.AllowCookies = item->permission();
+    siteSettings.ZoomLevel = -1;
+
+    siteSettings.server = mApp->siteSettingsManager()->adjustUrl(m_baseUrl);
+
+    auto storedSiteSettings = mApp->siteSettingsManager()->getSiteSettings(m_baseUrl);
+
+    if (!(siteSettings == storedSiteSettings)) {
+        mApp->siteSettingsManager()->setSiteSettings(siteSettings);
+
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        if (siteSettings.attributes[QWebEngineSettings::ForceDarkMode] != storedSiteSettings.attributes[QWebEngineSettings::ForceDarkMode]) {
+            bool enableForceDarkMode = false;
+
+            if (siteSettings.attributes[QWebEngineSettings::ForceDarkMode] == SiteSettingsManager::Default) {
+                enableForceDarkMode = mApp->siteSettingsManager()->getDefaultPermission(QWebEngineSettings::ForceDarkMode) == SiteSettingsManager::Allow;
+            }
+            else {
+                enableForceDarkMode = siteSettings.attributes[QWebEngineSettings::ForceDarkMode] == SiteSettingsManager::Allow;
+            }
+            m_view->page()->settings()->setAttribute(
+                QWebEngineSettings::ForceDarkMode,
+                enableForceDarkMode
+            );
+        }
+#endif
+    }
+}
